@@ -19,6 +19,12 @@ KNOWN_PKG_TYPES = [
     "conan",
     "pub",
     "hackage",
+    "android",
+    "dwf",
+    "gsd",
+    "hex",
+    "packagist",
+    "uvi",
 ]
 
 # Maps variations of string to package types
@@ -32,6 +38,8 @@ PKG_TYPES_MAP = {
     "rubygems": ["ruby", "gem"],
     "golang": ["go"],
     "crates": ["rust", "crates.io", "cargo"],
+    "pub": ["dart"],
+    "hex": ["elixir"],
 }
 
 # CPE Regex
@@ -220,7 +228,7 @@ class VulnerabilityDetail(object):
 
     @staticmethod
     def get_type(cpe_uri, package_type):
-        if package_type in KNOWN_PKG_TYPES:
+        if package_type and package_type in KNOWN_PKG_TYPES:
             return package_type
         parts = CPE_REGEX.match(cpe_uri)
         # cpe:2.3:a:netaddr_project:netaddr:*:*:*:*:*:ruby:*:*
