@@ -218,7 +218,10 @@ class NvdSource(VulnerabilitySource):
             for det in cpe_details_list:
                 if fix_cpe_uri:
                     det["fixed_location"] = fix_cpe_uri
-                details.append(VulnerabilityDetail.from_dict(det))
+                adetail = VulnerabilityDetail.from_dict(det)
+                # Include only the application details
+                if adetail and adetail.package_type not in config.nvd_exclude_types:
+                    details.append(adetail)
         if not details:
             return None
         return details
