@@ -1,3 +1,4 @@
+import string
 import importlib
 import re
 from datetime import date, datetime
@@ -242,6 +243,8 @@ def normalise_version_str(version_num, normal_len):
     >>> normalise_version_str(1.0.0, 4)
     1.0.0.0
     """
+    if checkHex(version_num):
+        return version_num
     version_num_parts = len(version_num.split("."))
     if version_num_parts < normal_len:
         for i in range(version_num_parts, normal_len):
@@ -273,6 +276,8 @@ def convert_to_semver(version):
         belong to a basic version.
     :rtype: tuple(:class:`VersionInfo` | None, str)
     """
+    if version and len(version) > 8 and checkHex(version):
+        return (None, None)
     match = BASEVERSION.search(version)
     if not match:
         return (None, version)
@@ -316,6 +321,29 @@ def convert_to_semver(version):
     return ver, rest
 
 
+def checkHex(s):
+    if not s:
+        return False
+    hex_digits = set(string.hexdigits)
+    return all(c in hex_digits for c in s)
+
+
+def is_hash_mode(
+    compare_ver,
+    min_version,
+    max_version,
+    min_affected_version_excluding,
+    max_affected_version_excluding,
+):
+    return (
+        checkHex(compare_ver)
+        or checkHex(min_version)
+        or checkHex(max_version)
+        or checkHex(min_affected_version_excluding)
+        or checkHex(max_affected_version_excluding)
+    )
+
+
 def version_compare(
     compare_ver,
     min_version,
@@ -334,6 +362,13 @@ def version_compare(
     >>> utils.version_compare("4.0.0", "2.0.0", "*")
     True
     """
+    hash_mode_detected = is_hash_mode(
+        compare_ver,
+        min_version,
+        max_version,
+        min_affected_version_excluding,
+        max_affected_version_excluding,
+    )
     # Semver compatible and including versions provided
     is_min_exclude = False
     is_max_exclude = False
@@ -492,6 +527,17 @@ def version_compare(
         is_max_exclude and compare_ver == max_version
     ):
         return False
+    if hash_mode_detected:
+        if compare_ver:
+            if compare_ver == min_version:
+                return True
+            if compare_ver == max_version:
+                return True
+            if compare_ver == min_affected_version_excluding:
+                return False
+            if compare_ver == max_affected_version_excluding:
+                return False
+        return False
     return True
 
 
